# <img src="https://code.visualstudio.com/assets/images/code-stable.png" height=24 /> Visual Studio Code Folder

This folder contains files needed to have a configured IDE experience with Visual Studio Code 💖

## Folder Contents:

* `extensions.json` : Contains recommend extensions for VS Code
* `launch.json` : Contains debug profiles for launching Python using VS Code
* `settings.json.template` : A set of recommended settings for VS Code to get best user experience
* `tasks.json` : Contains automation tasks for convenience
